'use strict';

const _rules = require('@commitlint/rules');
const constants = require('./shared/commitlint-config.4882fa67.cjs');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e.default : e; }

const _rules__default = /*#__PURE__*/_interopDefaultCompat(_rules);

const rules = _rules__default.default || _rules__default;
const index = {
  // For exclamation mark as `breaking change` support
  parserPreset: "conventional-changelog-conventionalcommits",
  // https://commitlint.js.org/#/reference-rules
  rules: {
    /**
     * No need to configure `header` separately from `scope`/`type`/`subject`
     */
    "header-case": [constants.OFF, "always", "sentence-case"],
    "header-full-stop": [constants.ERROR, "never", "."],
    "header-max-length": [constants.OFF, "always", 100],
    "header-min-length": [constants.OFF, "always", 3],
    /**
     * Type should be defined, one from list.
     */
    "type-enum": [constants.ERROR, "always", [
      "feat",
      "fix",
      "refactor",
      "perf",
      "test",
      "docs",
      "chore",
      "release",
      "revert",
      "build",
      "ci",
      "wip",
      "nvm"
    ]],
    "type-case": [constants.ERROR, "always", "lower-case"],
    "type-empty": [constants.ERROR, "never"],
    "type-max-length": [constants.OFF, "always", Infinity],
    "type-min-length": [constants.OFF, "always", 0],
    /**
     * Scope can be omitted, but if defined, it should be in lowercase.
     */
    "scope-enum": [constants.OFF, "always", []],
    // should be configured per-project
    "scope-case": [constants.ERROR, "always", "lower-case"],
    "scope-empty": [constants.OFF, "never"],
    "scope-max-length": [constants.OFF, "always", Infinity],
    "scope-min-length": [constants.OFF, "always", 0],
    /**
     * Subject should be in sentence case, have length between 3 and 100
     * and shouldn't ends with dot. Also allows `!` mark before `:`.
     */
    "subject-case": [constants.ERROR, "always", "sentence-case"],
    "subject-empty": [constants.ERROR, "never"],
    "subject-max-length": [constants.ERROR, "always", 100],
    "subject-min-length": [constants.ERROR, "always", 3],
    "subject-exclamation-mark": [constants.OFF, "never"],
    /**
     * Body can be omitted, but if defined, it starts with leading blank line,
     * should be written in sentence case and should ends with dot.
     */
    "body-full-stop": [constants.OFF, "always", "."],
    "body-leading-blank": [constants.ERROR, "always"],
    "body-empty": [constants.OFF, "never"],
    "body-max-length": [constants.OFF, "always", Infinity],
    "body-max-line-length": [constants.OFF, "always", Infinity],
    "body-min-length": [constants.OFF, "always", constants.OFF],
    // `body-case` is redefined via the local plugin below
    // to allow a single link as a body.
    "body-case": [constants.ERROR, "always", "sentence-case"],
    /**
     * Footer can be omitted, but if defined, it starts with leading blank line,
     * should be written in sentence case and should ends with dot.
     */
    "footer-leading-blank": [constants.ERROR, "always"],
    "footer-empty": [constants.OFF, "never"],
    "footer-max-length": [constants.OFF, "always", Infinity],
    "footer-max-line-length": [constants.OFF, "always", Infinity],
    "footer-min-length": [constants.OFF, "always", 0],
    /**
     * Other rules
     */
    "references-empty": [constants.OFF, "never"],
    "signed-off-by": [constants.OFF, "always", "Signed-off-by:"],
    "trailer-exists": [constants.OFF, "always", "Signed-off-by:"]
  },
  plugins: [
    {
      rules: {
        "body-case": (parsed, when, value) => {
          const originalResult = rules["body-case"](parsed, when, value);
          if (originalResult[0] === true)
            return originalResult;
          const onlyLink = /https?:\/\/\S+$/.test((parsed.body || "").trim());
          return onlyLink ? [true] : [false, `${originalResult[1]} or contain a single link`];
        }
      }
    }
  ]
};

module.exports = index;
